@@ -1,6 +1,6 @@
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.1.6';
+$Git::Repository::Plugin::GitHooks::VERSION = '2.1.7';
 use parent qw/Git::Repository::Plugin/;
 
 use 5.010;
@@ -607,15 +607,7 @@ sub error {
     my ($git, $prefix, $message, $details) = @_;
     $message =~ s/\n*$//s;    # strip trailing newlines
     my $fmtmsg = "\n[$prefix] $message";
-    if ($details) {
-        # The details may have been generated by Carp::croak, in which case
-        # it will contain a suffix telling where the error
-        # occurred. Sometimes you may not want this. For instance, if the
-        # user is going to receive the error message produced by a server
-        # hook he/she won't be able to use that information. So, we may have
-        # to strip the context from the details.
-        $details =~ s/ at .*? line \d+(?: thread \d+)?\.?$//s
-            if $git->get_config(githooks => 'nocarp');
+    if (defined $details) {
         $details =~ s/\n*$//s; # strip trailing newlines
         $details =~ s/^/  /gm; # prefix each line with two spaces
         $fmtmsg .= ":\n\n$details\n";
@@ -1140,7 +1132,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.1.6
+version 2.1.7
 
 =head1 SYNOPSIS
 
